@@ -148,7 +148,7 @@ class SelectQuery(DQLQuery):
                 converter = OuterJoinConverter(self, statement)
                 self.joins.append(converter)
 
-            elif tok.match(tokens.Keyword, 'GROUP'):
+            elif tok.match(tokens.Keyword, ['GROUP', 'GROUP BY']):
                 self.groupby = GroupbyConverter(self, statement)
 
             elif tok.match(tokens.Keyword, 'HAVING'):
@@ -962,7 +962,4 @@ class Query:
         'CREATE': _create,
         'DROP': _drop,
         'ALTER': _alter
-    }
-
-
-
+    }
\ No newline at end of file
